@@ -4,6 +4,7 @@ use Cwd;
 Alzabo::Config::root_dir( Cwd::cwd );
 
 $| = 1;
+$^W = 1;
 
 use vars qw( $COUNT );
 
@@ -11,6 +12,5 @@ sub ok
 {
     my $ok = !!shift;
     print $ok ? 'ok ': 'not ok ';
-    print ++$COUNT, "\n";
-    print "@_\n" if ! $ok;
+    print ++$COUNT, ! $ok ? " - @_\n" : "\n";
 }
